;pently for asm6, with modifications by Doug Fraker, June 2016

; Copyright 2010-2015 Damian Yerrick
;
; Copying and distribution of this file, with or without
; modification, are permitted in any medium without royalty provided
; the copyright notice and this notice are preserved in all source
; code copies.  This file is offered as-is, without any warranty.




; Ordinarily, the effect engine will move a pulse sound effect from
; $4000 to $4004 if $4004 is idle and $4000 is not, or if $4004 has
; less sfx data left to play than $4000.  Turn this off to force all
; pulse sfx to be played on $4000.
SQUARE_POOLING = 1

; As of 2011-03-10, a sound effect interrupts a musical instrument on
; the same channel only if the volume of the sfx is greater than that
; of the instrument.  Turn this off to force sound fx to interrupt
; the music whenever sfx data remains on that channel, even if the
; music is louder.
KEEP_MUSIC_IF_LOUDER = 1
NUM_SONGS = 5
SOUND_NTSC_ONLY = 0
PENTLY_USE_ROW_CALLBACK = 0



.include "define_stuff.asm"


;;;;;;;;;;;;;
;
;variables
;
;;;;;;;;;;;;;
ENUM $0000
reserved	;reserve 6 variables 0-5
	REPT 6
	.DB 0
	ENDR
nmis	.DB 0
tvSystem	.DB 0
oam_used	.DB 0
cur_song	.DB 0
cur_keys	.DB 0,0  ;.res 2
new_keys	.DB 0,0  ;.res 2


pently_zp_state ;.res 36
	REPT 36
	.DB 0
	ENDR

ENDE

ENUM $0300
pentlyBSS ;.res 88 ;in ram
	REPT 88
	.DB 0
	ENDR
ENDE





  .db "NES",$1A  ; magic signature
  .db 1          ; PRG ROM size in 16384 dbe units
  .db 1          ; CHR ROM size in 8192 dbe units
  .db $00        ; mirroring type and mapper number lower nibble
  .db $00        ; mapper number upper nibble
.hex 0 0 0 0 0 0 0 0



.org $c000






reset:
  sei             
  ldx #$00
  stx PPUCTRL     
  stx PPUMASK     
  stx $4010       
  dex             
  txs             
  bit PPUSTATUS   
  bit SNDCHN      
  lda #$40
  sta P2          
  lda #$0F
  sta SNDCHN      

vwait1:
  bit PPUSTATUS   
  bpl vwait1      
  cld
  
   lda #$00
   ldx #$00
Blankram:
	sta $00, x
	sta $0100, x
	sta $0200, x
	sta $0300, x
	sta $0400, x
	sta $0500, x
	sta $0600, x
	sta $0700, x
	inx
	bne Blankram
  
  
  ldx #0
  stx cur_song			;set song to zero
  jsr ppu_clear_oam
  jsr pently_init		;after RAM blanked, call init

vwait2:
  bit PPUSTATUS 
  bpl vwait2    
  
  jsr display_todo
  jsr getTVSystem		;get tv system
  sta tvSystem
  
  lda cur_song
  jsr pently_start_music	;start a song

  
  
  
forever:
  lda #0
  sta oam_used

  lda #8
  tax
  lda cur_song
  asl a
  asl a
  asl a
  clc
  adc #27
  tay
  lda #0
  jsr draw_y_arrow_sprite

  jsr getCurBeatFraction
  clc
  adc #64
  tax
  ldy #219
  lda #0
  jsr draw_y_arrow_sprite
  
  ldx oam_used
  jsr ppu_clear_oam

  lda nmis
-
  cmp nmis
  beq -

  lda #VBLANK_NMI
  sta PPUCTRL
  lda #$23
  sta PPUADDR
  lda #$62
  sta PPUADDR
  lda pently_row_beat_part
  beq +
  lda #$14; ;#'.'^':'
+
  eor #$3a;  #':'
  sta PPUDATA
  lda pently_row_beat_part
  and #$0F
  ora #$30 ;'0'
  sta PPUDATA
  lda #$2f ;'/'
  sta PPUDATA
  lda pently_rows_per_beat
  and #$0F
  ora #$30 ;'0'
  sta PPUDATA
  
  ldx #0
  stx OAMADDR
  lda #>OAM
  sta OAM_DMA
  ldy #0
  lda #VBLANK_NMI|BG_0000|OBJ_0000
  sec
  jsr ppu_screen_on

  jsr pently_update			;call update once per frame
  jsr read_pads
  
  lda new_keys
  and #KEY_DOWN
  beq notDown
  inc cur_song
  lda cur_song
  cmp #NUM_SONGS
  bcc notWrapDown
  lda #0
  sta cur_song
notWrapDown:
  jsr pently_start_music	;start a new song
notDown:

  lda new_keys
  and #KEY_UP
  beq notUp
  dec cur_song
  lda cur_song
  cmp #NUM_SONGS
  bcc notWrapUp
  lda #NUM_SONGS-1
  sta cur_song
notWrapUp:
  jsr pently_start_music
notUp:

  jmp forever
  
  
.include "not_pently.asm"
  
  
nmi:
  inc nmis
irq:
  rti

  
.include "pently_asm6.asm"

.include "songs2.asm"
  
  
  

main_palette:
  .db $0F,$00,$10,$30, $0F,$00,$10,$30, $0F,$00,$10,$30, $0F,$00,$10,$30
  .db $0F,$00,$10,$30, $0F,$00,$10,$30, $0F,$00,$10,$30, $0F,$00,$10,$30
  
tracknames_txt:
  .incbin "tracknames.txt"
  .db 0

	.org $fffa
	.dw nmi, reset, irq


	.incbin "bggfx.chr"